@@ -101,11 +101,11 @@ COMMANDS = {
     "ipv4-restore": "/usr/bin/iptables-restore",
     "ipv6": "/usr/bin/ip6tables",
     "ipv6-restore": "/usr/bin/ip6tables-restore",
-    "eb": "/bin/false",
-    "eb-restore": "/bin/false",
+    "eb": "/usr/bin/ebtables",
+    "eb-restore": "/usr/bin/ebtables-restore",
     "ipset": "/bin/false",
-    "modprobe": "/usr/bin/modprobe",
-    "rmmod": "/usr/bin/rmmod",
+    "modprobe": "/sbin/modprobe",
+    "rmmod": "/sbin/rmmod",
 }
 
 LOG_DENIED_VALUES = ["all", "unicast", "broadcast", "multicast", "off"]
